package com.bweb.controller.goods;

import com.bweb.controller.FileUploadController;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.SessionObject;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.GoodsType;
import com.hfkj.entity.SecMenu;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.goods.GoodsTypeService;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

public class GoodsTypeController {
    private static final Logger log = LoggerFactory.getLogger(FileUploadController.class);

    @Resource
    private GoodsTypeService goodsTypeService;

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value="/editMenu",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "编辑菜单")
    public ResponseData editMenu(@RequestBody GoodsType body, HttpServletRequest request) {

        SessionObject sessionObject = userCenter.getSessionObject(request);
        SecUserSessionObject userModel = (SecUserSessionObject) sessionObject.getObject();

        if (body == null
                || body.getBusinessType() == null
                || StringUtils.isBlank(body.getTitle())) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
        }

        GoodsType goodsType;

        if (body.getId() != null) {
            // 查询商品类型
            goodsType = goodsTypeService.queryDetail(body.getId());
            if (goodsType == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
        } else {
            goodsType = new GoodsType();
            goodsType.setCreateTime(new Date());
        }

        goodsType.setUpdateTime(new Date());
        goodsType.setStatus(1);
        goodsType.setParentId(body.getParentId());
        goodsType.setBusinessType(body.getBusinessType());
        goodsType.setImgUrl(body.getImgUrl());
        goodsType.setOpId(userModel.getAccount().getId());
        goodsType.setOpName(userModel.getAccount().getUserName());

        if (body.getId() != null) {
            goodsTypeService.update(goodsType);
        } else {
            goodsTypeService.create(goodsType);
        }

        return ResponseMsgUtil.success("操作成功");
    }

    @RequestMapping(value="/getList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询列表")
    public ResponseData getList(
            @RequestParam(value = "parentId" , required = false) Long parentId,
                                    @RequestParam(value = "businessType" , required = false) Integer businessType,
                                    @RequestParam(value = "title" , required = false) String title
    ) {
        try {

            Map<String , Object> map = new HashMap<>();
            map.put("parentId" , parentId);
            map.put("businessType" , businessType);
            map.put("title" , title);

            return ResponseMsgUtil.success(goodsTypeService.getList(map));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/delete",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData delete(@RequestParam(value = "id" , required = false) Long id) {
        try {

            goodsTypeService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
